SHA2_256_Portable

Struct SHA2_256_Portable 

pub struct SHA2_256_Portable { /* private fields */ }
A portable implementation of the SHA2-256 algorithm.

This implementation is portable, will work on any platform and is const friendly.

Notes

The concrete algorithm follows closely the SHA2-256 specification taken from RFC 4634.

Implementations

Source

impl SHA2_256_Portable

pub const fn new() -> Self

Creates a new SHA2_256_Portable instance.

pub const fn update_const(&mut self, data: &[u8])

Writes a block of data to the underlying state.

Panics

This function will panic if the length of the data is greater than u32::MAX, and when the total processed length exceeds u64::MAX.

pub const fn write_result_const(&self, output: &mut [u8; 32])

Writes the final has value to the passed output.

Notes

This function does not update the internal state, and thus the SHA2_256_Portable can still be used afterwards.

pub const fn result_const(&self) -> [u8; 32]

Returns the final hash value.

Notes

This function does not update the internal state, and thus the SHA2_256_Portable can still be used afterwards.