pub struct SHA2_256_Portable { /* private fields */ }Expand description
Implementations
Sourceimpl SHA2_256_Portable
impl SHA2_256_Portable
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Creates a new SHA2_256_Portable instance.
Sourcepub const fn update_const(&mut self, data: &[u8])
pub const fn update_const(&mut self, data: &[u8])
Writes a block of data to the underlying state.
Panics
This function will panic if the length of the data is greater than u32::MAX,
and when the total processed length exceeds u64::MAX.
Sourcepub const fn write_result_const(&self, output: &mut [u8; 32])
pub const fn write_result_const(&self, output: &mut [u8; 32])
Writes the final has value to the passed output.
Notes
This function does not update the internal state, and thus
the SHA2_256_Portable can still be used afterwards.
Sourcepub const fn result_const(&self) -> [u8; 32]
pub const fn result_const(&self) -> [u8; 32]
Returns the final hash value.
Notes
This function does not update the internal state, and thus
the SHA2_256_Portable can still be used afterwards.